#!/usr/bin/env python
# -*- coding: utf-8 -*-

# @Time :2023/3/8 
# @Author :wsli
# @File : py_time.py
# @Software: PyCharm
import time
class Bruce_time:
    def now_default_time(self):
        """
        当前年月日时分秒
        :return:
        """
        return time.strftime('%Y-%m-%d %H:%M:%S')

    def time_add_poor(self):
        """
        时间差
        :return:
        """
        pass